# Export
### On this page
  * [Exporting Workspace Data](https://help.sap.com/docs/leanix/ea/export#exporting-workspace-data)
  * [Viewing the Export History](https://help.sap.com/docs/leanix/ea/export#viewing-the-export-history)
  * [Automating Exports](https://help.sap.com/docs/leanix/ea/export#automating-exports)


Export your workspace data and view the export history.
In the Export section of the administration area, you can export your workspace data to an XLSX file and view the export history.
